@@ -4,7 +4,7 @@ extension_name = 'ox'
 dir_config(extension_name)
 
 parts = RUBY_DESCRIPTION.split(' ')
-type = parts[0].downcase()
+type = parts[0].downcase
 type = 'ree' if 'ruby' == type && RUBY_DESCRIPTION.include?('Ruby Enterprise Edition')
 platform = RUBY_PLATFORM
 version = RUBY_VERSION.split('.')
@@ -16,10 +16,10 @@ dflags = {
   'RUBY_VERSION' => RUBY_VERSION,
   'RUBY_VERSION_MAJOR' => version[0],
   'RUBY_VERSION_MINOR' => version[1],
-  'RUBY_VERSION_MICRO' => version[2],
+  'RUBY_VERSION_MICRO' => version[2]
 }
 
-dflags.each do |k,v|
+dflags.each do |k, v|
   if v.nil?
     $CPPFLAGS += " -D#{k}"
   else
@@ -27,19 +27,14 @@ dflags.each do |k,v|
   end
 end
 $CPPFLAGS += ' -Wall'
-#puts "*** $CPPFLAGS: #{$CPPFLAGS}"
+# puts "*** $CPPFLAGS: #{$CPPFLAGS}"
 CONFIG['warnflags'].slice!(/ -Wsuggest-attribute=format/)
 CONFIG['warnflags'].slice!(/ -Wdeclaration-after-statement/)
 CONFIG['warnflags'].slice!(/ -Wmissing-noreturn/)
 
-have_func('rb_time_timespec')
-have_func('rb_struct_alloc_noinit')
-have_func('rb_obj_encoding')
-have_func('rb_ivar_foreach')
 have_func('rb_ext_ractor_safe', 'ruby.h')
 have_func('pthread_mutex_init')
 have_func('rb_enc_interned_str')
-have_func('rb_time_nano_new')
 have_func('index')
 
 have_header('ruby/st.h')
@@ -49,4 +44,4 @@ have_struct_member('struct tm', 'tm_gmtoff')
 
 create_makefile(extension_name)
 
-%x{make clean}
+`make clean`
