@@ -1,4 +1,3 @@
-
 module Ox
   # Represents an XML document. It has a fixed set of attributes which form
   # the XML prolog. A Document includes Elements.
@@ -10,14 +9,14 @@ module Ox
     #   - _:standalone_ [String] indicates the document is standalone
     def initialize(prolog={})
       super(nil)
-      @attributes = { }
+      @attributes = {}
       @attributes[:version] = prolog[:version] unless prolog[:version].nil?
       @attributes[:encoding] = prolog[:encoding] unless prolog[:encoding].nil?
       @attributes[:standalone] = prolog[:standalone] unless prolog[:standalone].nil?
     end
-    
+
     # Returns the first Element in the document.
-    def root()
+    def root
       unless !instance_variable_defined?(:@nodes) || @nodes.nil?
         @nodes.each do |n|
           return n if n.is_a?(::Ox::Element)
@@ -25,6 +24,5 @@ module Ox
       end
       nil
     end
-
   end # Document
 end # Ox
