@@ -1,10 +1,9 @@
-
 module Ox
   # The Node is the base class for all other in the Ox module.
   class Node
     # String value associated with the Node.
     attr_accessor :value
-    
+
     # Creates a new Node with the specified String value.
     # - +value+ [String] string value for the Node
     def initialize(value)
@@ -16,9 +15,9 @@ module Ox
     # - +other+ [Object] Object to compare _self_ to.
     def eql?(other)
       return false if (other.nil? or self.class != other.class)
-      other.value == self.value
+
+      other.value == value
     end
     alias == eql?
-
   end # Node
 end # Ox
