@@ -90,7 +90,7 @@ if do_load
   puts 'Load Performance'
   perf = Perf.new
   perf.add('Ox', 'load') { Ox.load($xml, mode: :object) }
-  perf.add('Oj', 'load') { Oj.load($json) } unless (defined?(Oj).nil? || ox_only)
+  perf.add('Oj', 'load') { Oj.load($json) } unless defined?(Oj).nil? || ox_only
   perf.add('Marshal', 'load') { Marshal.load($mars) } unless ox_only
   perf.run($iter)
 end
@@ -100,7 +100,7 @@ if do_dump
   puts 'Dump Performance'
   perf = Perf.new
   perf.add('Ox', 'dump') { Ox.dump($obj, indent: $indent, circular: $circular) }
-  perf.add('Oj', 'dump') { Oj.dump($obj) } unless (defined?(Oj).nil? || ox_only)
+  perf.add('Oj', 'dump') { Oj.dump($obj) } unless defined?(Oj).nil? || ox_only
   perf.add('Marshal', 'dump') { Marshal.dump($obj) } unless ox_only
   perf.run($iter)
 end
@@ -110,7 +110,7 @@ if do_read
   puts 'Read from file Performance'
   perf = Perf.new
   perf.add('Ox', 'load_file') { Ox.load_file('sample.xml', mode: :object) }
-  perf.add('Oj', 'load') { Oj.load_file('sample.json') } unless (defined?(Oj).nil? || ox_only)
+  perf.add('Oj', 'load') { Oj.load_file('sample.json') } unless defined?(Oj).nil? || ox_only
   perf.add('Marshal', 'load') { Marshal.load(File.new('sample.marshal')) } unless ox_only
   perf.run($iter)
 end
@@ -120,7 +120,7 @@ if do_write
   puts 'Write to file Performance'
   perf = Perf.new
   perf.add('Ox', 'to_file') { Ox.to_file('sample.xml', $obj, indent: $indent, circular: $circular) }
-  perf.add('Oj', 'to_file') { Oj.to_file('sample.json', $obj) } unless (defined?(Oj).nil? || ox_only)
+  perf.add('Oj', 'to_file') { Oj.to_file('sample.json', $obj) } unless defined?(Oj).nil? || ox_only
   perf.add('Marshal', 'dump') { Marshal.dump($obj, File.new('sample.marshal', 'w')) } unless ox_only
   perf.run($iter)
 end
