@@ -1,23 +1,22 @@
-
 require 'time'
 require 'nokogiri'
 
 module Weather
   class WNoSax < ::Nokogiri::XML::SAX::Document
-
     attr_accessor :highs
 
     def self.parse(filename, as_time)
-      handler = self.new(as_time)
+      handler = new(as_time)
       nohand = Nokogiri::XML::SAX::Parser.new(handler)
       input = IO.open(IO.sysopen(filename))
       nohand.parse(input)
       input.close
-      #puts handler.highs
+      # puts handler.highs
       handler.highs
     end
 
     def initialize(as_time)
+      super
       @as_time = as_time
       @highs = {}
       @time = nil
@@ -38,18 +37,19 @@ module Weather
     def characters(text)
       text.strip!
       return if text.empty?
-      if 1 < @row
-        case @cell
-        when 2
-          if @as_time
-            #@time = Time.parse(text)
-            @time = Time.at(text.to_f)
-          else
-            @time = text
-          end
-        when 4
-          @highs[@time] = text.to_f
+
+      return unless 1 < @row
+
+      case @cell
+      when 2
+        if @as_time
+          # @time = Time.parse(text)
+          @time = Time.at(text.to_f)
+        else
+          @time = text
         end
+      when 4
+        @highs[@time] = text.to_f
       end
     end
 
@@ -60,6 +60,5 @@ module Weather
     def warning(message)
       puts message
     end
-
   end # WNoSax
 end # Weather
